@@ -39,8 +39,8 @@ def compete_add(forest,network_ids=-1,radius_buffer=0.05,exact=True):
     #networks_copy = deepcopy(forest.networks)
     #unused_networks = list(set(all_network_ids) - set(active_network_ids))
     while len(active_network_ids) > 0:
-        for nid in active_network_ids:
-            for njd in active_network_tree_ids[nid]:
+        for ii, nid in enumerate(active_network_ids):
+            for njd in active_network_tree_ids[ii]:
                 repeat = True
                 while repeat:
                     ## Preallocate points to check for new vessel appending
@@ -152,8 +152,8 @@ def compete_add(forest,network_ids=-1,radius_buffer=0.05,exact=True):
                         forest.networks[nid][njd].sub_division_map = sub_division_map
                         forest.networks[nid][njd].sub_division_index = sub_division_index
                         #print("List {}: {},  Id: {}".format(nid,active_network_tree_ids[nid],njd))
-                        active_network_tree_ids[nid].remove(njd)
-                        if len(active_network_tree_ids[nid]) == 0:
+                        active_network_tree_ids[ii].remove(njd)
+                        if len(active_network_tree_ids[ii]) == 0:
                             active_network_ids.remove(nid)
                         #print("Active Networks: {}".format(active_network_ids))
     forest.boundary.volume = volume
